// Copyright (C) 2009 - Digiteo - Michael Baudin


// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

// A Scilab port of the AxialStressedBeam.py demo of Open Turns
// TODO : finish this !

function p = lognormalpdf ( x , mu , sigma )
  ii = find ( x<=0 )
  p(ii) = 0
  ii = find ( x>0 )
  c = (log(x(ii)) - mu)/sigma
  p(ii) = exp ( -0.5 * c^2 ) ./ ( sigma * x(ii) * sqrt(2*%pi) )
endfunction

function p = lognormalcdf ( x , mu , sigma )
  ii = find ( x<=0 )
  p(ii) = 0
  ii = find ( x>0 )
  c = - (log(x(ii)) - mu)/sigma/sqrt(2)
  p(ii) = 0.5 * erfc ( c )
endfunction

//
// normpdf --
//   Computes the Normal probability distribution function
// Arguments
//   x : the outcome
//   mu : the mean (default 0)
//   sigma : the standard deviation (default 1)
//   p : the probability
// Calling sequences
//   p = normpdf ( x )
//   p = normpdf ( x , mu , sigma )
//
function p = normpdf ( varargin )
  [lhs,rhs]=argn();
  if ( ( rhs <> 1 ) & ( rhs <> 3 ) ) then
    errmsg = msprintf(gettext("%s: Unexpected number of input arguments : %d provided while %d or %d are expected."), "normpdf" , rhs , 1 , 3 );
    error(errmsg)
  end
  select rhs
  case 1 then
    x = varargin ( 1 )
    mu = 0.0
    sigma = 1.0
  case 3 then
    x = varargin ( 1 )
    mu = varargin ( 2 )
    sigma = varargin ( 3 )
  end
  y = ( x - mu ) ./ sigma;
  p = exp ( - 0.5 .* y .* y )  ./ ( sigma .* sqrt ( 2.0 * %pi ) );
endfunction


// Random generator initialization:
nisp_initseed(0)

// Analytical model definition:
function G = LimitState ( x )
  R = x(1)
  F = x(2)
  G = R-F/(%pi*100)
endfunction
// Test of the limit state function:
x = [300.0 75000.0];
mprintf ("x=[%s]" , strcat ( string ( x ) , " " ) );
mprintf ("G(x)=%f" , LimitState(x) );

// Initialization of the distribution collection:
srv = setrandvar_new ( );

// Create a first marginal : LogNormal distribution 1D, parameterized by its mean and standard deviation
vu1 = randvar_new("LogNormale" , 300.0 , 30.0 );
// Graphical output of the PDF
x = linspace ( 200 , 400 , 1000 );
E = 300;
V = 30^2;
mu = log(E) - 0.5 * log ( 1 + V/E^2 );
sigma = sqrt ( log ( 1 + V/E^2 ) );
p = lognormalpdf ( x , mu , sigma );
scf();
plot ( x , p );
xtitle ( "Yield strength PDF" , "X" , "PDF" );
legend ( "Yield strength PDF" );
// Fill the first marginal 
setrandvar_addrandvar ( srv , vu1 );

// Create a second marginal : Normal distribution 1D
vu2 = randvar_new("Normale" , 75000.0 , 5000.0 );
// Graphical output of the PDF
x = linspace ( 60000 , 90000 , 1000 );
p = normpdf ( x , 75000.0 , 5000.0 );
scf();
plot ( x , p );
xtitle ( "Traction_load PDF" , "X" , "PDF" );
legend ( "Traction_load PDF" );
// Fill the second marginal of aCollection
setrandvar_addrandvar ( srv , vu2 );

// TODO : finish this !


