// Copyright (C) 2009 - CEA - Jean-Marc Martinez
// Copyright (C) 2009-2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html



function y = ishigami (x)
  a=7.;
  b=0.1;
  s1=sin(x(1));
  s2=sin(x(2));
  y(1) = s1 + a*s2*s2 + b*x(3)*x(3)*x(3)*x(3)*s1;
endfunction

// Reprsentation du groupe des variables stochastiques
nx = 3;
srvx = setrandvar_new( nx );

// 4.1 Reprsentation des paramtres incertains
rvu1 = randvar_new("Uniforme",-%pi,%pi);
rvu2 = randvar_new("Uniforme",-%pi,%pi);
rvu3 = randvar_new("Uniforme",-%pi,%pi);

srvu = setrandvar_new();
setrandvar_addrandvar ( srvu, rvu1);
setrandvar_addrandvar ( srvu, rvu2);
setrandvar_addrandvar ( srvu, rvu3);

degre = 9;
setrandvar_buildsample(srvx,"Petras",degre);
setrandvar_buildsample( srvu , srvx );

// Polynome de chaos
pc = polychaos_new ( srvx , 1 );
polychaos_setdegree(pc,degre);

// Ralisation du plan d'expriences numriques
np = setrandvar_getsize(srvu);
polychaos_setsizetarget(pc,np);
for k=1:np
  inputdata = setrandvar_getsample(srvu,k);
  outputdata = ishigami(inputdata);
  polychaos_settarget(pc,k,outputdata);
end

// Calcul des coefficients
polychaos_computeexp(pc,srvx,"Integration");

// 4.6 Edition de l'analyse de sensibilit
average = polychaos_getmean(pc);
var = polychaos_getvariance(pc);

mprintf("Mean        = %f\n",average);
mprintf("Variance    = %f\n",var);
if ( %f ) then
mprintf("Indice de sensibilit du 1er ordre\n");
mprintf("    Variable X1 = %f\n",polychaos_getindexfirst(pc,1));
mprintf("    Variable X2 = %f\n",polychaos_getindexfirst(pc,2));
mprintf("    Variable X3 = %f\n",polychaos_getindexfirst(pc,3));
mprintf("Indice de sensibilite Totale\n");
mprintf("    Variable X1 = %f\n",polychaos_getindextotal(pc,1));
mprintf("    Variable X2 = %f\n",polychaos_getindextotal(pc,2));
mprintf("    Variable X3 = %f\n",polychaos_getindextotal(pc,3));
else
// Plus court !
disp (" Indice du 1er ordre : "); disp ( polychaos_getindexfirst (pc )')
disp (" Indice Totaux : "); disp ( polychaos_getindextotal (pc )')
end

// Calcul de la part d'incertitude explique par
// le groupe des variables X1 et X2
groupe = [1 3];
polychaos_setgroupempty ( pc );
polychaos_setgroupaddvar ( pc , groupe(1) );
polychaos_setgroupaddvar ( pc , groupe(2) );
mprintf("Part de la variance d''un groupe de variables\n");
mprintf("    Groupe X1 et X2 =%f\n",polychaos_getgroupind(pc));

// Edition de la dcomposition fonctionnelle de la variance
// la ligne 1 0 1 indique le groupe de variables X1 et X3
// la valeur qui suit, indiquera la part de la variance explique par ce groupe
// La somme de tous les termes est gale  1 (variance normalise)
mprintf("Dcomposition fonctionnelle de variance normalise \n");
polychaos_getanova(pc);

// Tracer de l'histogramme illustrant la densit de probabilit de la rponse
// approche par le polynme de chaos
polychaos_buildsample(pc,"Lhs",10000,0);
sample_output = polychaos_getsample(pc);
my_handle = scf(10001);
histplot(50,sample_output)
xtitle("Fonction Ishigami - Histogramme normalis");

// Tracer des indices de sensibilit
for i=1:nx
  indexfirst(i)=polychaos_getindexfirst(pc,i);
  indextotal(i)=polychaos_getindextotal(pc,i);
end
my_handle = scf(10002);
bar(indextotal,0.2,'blue');
bar(indexfirst,0.15,'yellow');
//legend(["totale" "premier ordre"],opt=5);
legend(["totale" "premier ordre"],pos=1);
xtitle("Fonction Ishigami - Indice de sensibilit");
//
// Clean-up
//
randvar_destroy ( rvu1 );
randvar_destroy ( rvu2 );
randvar_destroy ( rvu3 );
setrandvar_destroy ( srvu );
polychaos_destroy ( pc );
setrandvar_destroy ( srvx );
//
// Load this script into the editor
//
filename = 'polychaos_ishigami.sce';
dname = get_absolute_file_path(filename);
editor ( dname + filename );

