// Copyright (C) 2009 - CEA - Jean-Marc Martinez
// Copyright (C) 2009-2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

//
// Using the meta-model associated with Ishigami
//

function y = ishigami (x)
  a=7.;
  b=0.1;
  s1=sin(x(1));
  s2=sin(x(2));
  y(1) = s1 + a*s2*s2 + b*x(3)*x(3)*x(3)*x(3)*s1;
endfunction

// Reprsentation du groupe des variables stochastiques
nx = 3;
rvx1 = randvar_new("Uniforme");
rvx2 = randvar_new("Uniforme");
rvx3 = randvar_new("Uniforme");

srvx = setrandvar_new( );
setrandvar_addrandvar ( srvx , rvx1 );
setrandvar_addrandvar ( srvx , rvx2 );
setrandvar_addrandvar ( srvx , rvx3 );

// 4.1 Reprsentation des paramtres incertains
rvu1 = randvar_new("Uniforme",-%pi,%pi);
rvu2 = randvar_new("Uniforme",-%pi,%pi);
rvu3 = randvar_new("Uniforme",-%pi,%pi);

srvu = setrandvar_new();
setrandvar_addrandvar ( srvu, rvu1);
setrandvar_addrandvar ( srvu, rvu2);
setrandvar_addrandvar ( srvu, rvu3);

degre = 9;
setrandvar_buildsample(srvx,"Petras",degre);
setrandvar_buildsample( srvu , srvx );

// Polynome de chaos
pc = polychaos_new ( srvx , 1 );
polychaos_setdegree(pc,degre);

// Ralisation du plan d'expriences numriques
np = setrandvar_getsize(srvu);
polychaos_setsizetarget(pc,np);
for k=1:np
  inputdata = setrandvar_getsample(srvu,k);
  outputdata = ishigami(inputdata);
  polychaos_settarget(pc,k,outputdata);
end

// Calcul des coefficients
polychaos_computeexp(pc,srvx,"Integration");

/////////////////////////////////////////////////////////////////

// input of the polynomial : in [0,1]
x = [0.15 0.30 0.45];     
// input of ishigami : in [-pi,pi]
// We could directly set u = (x - 0.5) * 2. * %pi; 
// but the following is more general:
u(1) = randvar_getvalue ( rvu1 , rvx1 , x(1) )
u(2) = randvar_getvalue ( rvu2 , rvx2 , x(2) )
u(3) = randvar_getvalue ( rvu3 , rvx3 , x(3) )

// A first method
polychaos_computeoutput ( pc , x );
yp = polychaos_getoutput ( pc ) ;
ys = ishigami(u);
mprintf("polynome = %e, ishigami = %e\n",yp,ys);

// A second method
polychaos_setinput ( pc , x );
polychaos_computeoutput ( pc );
yp = polychaos_getoutput ( pc ) ;
mprintf("polynome = %e, ishigami = %e\n",yp,ys);

/////////////////////////////////////////////////////////////////

//
// Clean-up
//
randvar_destroy ( rvu1 );
randvar_destroy ( rvu2 );
randvar_destroy ( rvu3 );
randvar_destroy ( rvx1 );
randvar_destroy ( rvx2 );
randvar_destroy ( rvx3 );
setrandvar_destroy ( srvu );
polychaos_destroy ( pc );
setrandvar_destroy ( srvx );
//
// Load this script into the editor
//
filename = 'polychaos_ishigamimetamodel.sce';
dname = get_absolute_file_path(filename);
editor ( dname + filename );

