// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html
//
// Un petit exemple, adapté du document de spécification
//
// "Specifications scientifiques et informatiques : Chaos Polynomial"
// D-WP1/08/01/A 
// MARTINEZ JM. - CEA
//

function y = Exemple (x)
  y(1) = x(1) * x(2);
endfunction
// 1. Two stochastic (normalized) variables
vx1 = randvar_new("Normale");
vx2 = randvar_new("Uniforme");
// 2. A collection of stoch. variables.
srvx = setrandvar_new();
setrandvar_addrandvar ( srvx,vx1);
setrandvar_addrandvar ( srvx,vx2);
// 3. Two uncertain parameters
vu1 = randvar_new("Normale",1.0,0.5);
vu2 = randvar_new("Uniforme",1.0,2.5);
// 4. A collection of uncertain parameters
srvu = setrandvar_new();
setrandvar_addrandvar ( srvu,vu1);
setrandvar_addrandvar ( srvu,vu2);
// 5. Create the Design Of Experiments
degre = 2;
setrandvar_buildsample(srvx,"Quadrature",degre);
setrandvar_buildsample( srvu , srvx );
// 6. Create the polynomial
ny = 1;
pc = polychaos_new ( srvx , ny );
np = setrandvar_getsize(srvx);
polychaos_setsizetarget(pc,np);
// 7. Perform the DOE
for k=1:np
  inputdata = setrandvar_getsample(srvu,k);
  outputdata = Exemple(inputdata);
  polychaos_settarget(pc,k,outputdata);
end
// 8. Compute the coefficients of the polynomial expansion
polychaos_setdegree(pc,degre);
polychaos_computeexp(pc,srvx,"Integration");
// 9. Get the sensitivity indices
average = polychaos_getmean(pc);
var = polychaos_getvariance(pc);
mprintf("Mean    = %f\n",average);
mprintf("Variance    = %f\n",var);
mprintf("Indice de sensibilité du 1er ordre\n");
mprintf("    Variable X1 = %f\n",polychaos_getindexfirst(pc,1));
mprintf("    Variable X2 = %f\n",polychaos_getindexfirst(pc,2));
mprintf("Indice de sensibilite Totale\n");
mprintf("    Variable X1 = %f\n",polychaos_getindextotal(pc,1));
mprintf("    Variable X2 = %f\n",polychaos_getindextotal(pc,2));
// Clean-up
polychaos_destroy(pc);
randvar_destroy(vu1);
randvar_destroy(vu2);
randvar_destroy(vx1);
randvar_destroy(vx2);
setrandvar_destroy(srvu);
setrandvar_destroy(srvx);
//
// Load this script into the editor
//
filename = 'polychaos_product.sce';
dname = get_absolute_file_path(filename);
editor ( dname + filename );

