// Copyright (C) 2008-2011 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html
//
// Un petit exemple, adapte du document de specification
//
// "Specifications scientifiques et informatiques : Chaos Polynomial"
// D-WP1/08/01/A 
// MARTINEZ JM. - CEA
//
tic();

function y = Exemple (x)
  y(1) = x(1) * x(2);
endfunction
// First variable
// Normal
mu1 = 1.5;
sigma1 = 0.5;
// Second variable
// Normal
mu2 = 3.5;
sigma2 = 2.5;

// 1. Two stochastic (normalized) variables
vx1 = randvar_new("Normale");
vx2 = randvar_new("Normale");
// 2. A collection of stoch. variables.
srvx = setrandvar_new();
setrandvar_addrandvar ( srvx,vx1);
setrandvar_addrandvar ( srvx,vx2);
// 3. Two uncertain parameters
vu1 = randvar_new("Normale",mu1,sigma1);
vu2 = randvar_new("Normale",mu2,sigma2);
// 4. A collection of uncertain parameters
srvu = setrandvar_new();
setrandvar_addrandvar ( srvu,vu1);
setrandvar_addrandvar ( srvu,vu2);
// 5. Create the Design Of Experiments
degre = 2;
setrandvar_buildsample(srvx,"Quadrature",degre);
setrandvar_buildsample( srvu , srvx );
// 6. Create the polynomial
ny = 1;
pc = polychaos_new ( srvx , ny );
np = setrandvar_getsize(srvx);
mprintf("Number of experiments : %d\n",np);
polychaos_setsizetarget(pc,np);
// 7. Perform the DOE
for k=1:np
  inputdata = setrandvar_getsample(srvu,k);
  outputdata = Exemple(inputdata);
  polychaos_settarget(pc,k,outputdata);
end
// 8. Compute the coefficients of the polynomial expansion
polychaos_setdegree(pc,degre);
polychaos_computeexp(pc,srvx,"Integration");
// 9. Get the sensitivity indices
average = polychaos_getmean(pc);
Ey_expectation= mu1*mu2;
var = polychaos_getvariance(pc);
Vy_expectation = mu2^2*sigma1^2 + mu1^2*sigma2^2 + sigma1^2*sigma2^2;
mprintf("Mean    = %f (expectation = %f)\n",average,Ey_expectation);
mprintf("Variance    = %f (expectation = %f)\n",var,Vy_expectation);
mprintf("Indice de sensibilite du 1er ordre\n");
S1 = polychaos_getindexfirst(pc,1);
S1_expectation = ( mu2^2*sigma1^2 ) / Vy_expectation;
mprintf("    Variable X1 = %f (expectation = %f)\n",S1,S1_expectation);
re = abs(S1- S1_expectation)/S1_expectation;
mprintf("        Relative Error = %f\n", re);
S2 = polychaos_getindexfirst(pc,2);
S2_expectation = ( mu1^2*sigma2^2 ) / Vy_expectation;
mprintf("    Variable X2 = %f (expectation = %f)\n",S2,S2_expectation);
re = abs(S2- S2_expectation)/S2_expectation;
mprintf("        Relative Error = %f\n", re);

mprintf("Indice de sensibilite Totale\n");
mprintf("    Variable X1 = %f\n",polychaos_getindextotal(pc,1));
mprintf("    Variable X2 = %f\n",polychaos_getindextotal(pc,2));
// Clean-up
polychaos_destroy(pc);
randvar_destroy(vu1);
randvar_destroy(vu2);
randvar_destroy(vx1);
randvar_destroy(vx2);
setrandvar_destroy(srvu);
setrandvar_destroy(srvx);
//
// Load this script into the editor
//
filename = 'polychaos_product2.sce';
dname = get_absolute_file_path(filename);
editor ( dname + filename );

t = toc();
mprintf("Time = %f (s)\n", t);

