// Copyright (C) 2009 - CEA - Jean-Marc Martinez
// Copyright (C) 2009-2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

//
// Compute the first order sensitivity indices, the Homma-Saltelli way.
//

tic();

function y = Exemple (x)
  y(:,1) = x(:,1) .* x(:,2)
endfunction

// First variable
// Normal
mu1 = 1.5;
sigma1 = 0.5;
// Second variable
// Normal
mu2 = 3.5;
sigma2 = 2.5;

// Begin with np = 10.
// Serious computation is with np > 100000.
np = 100000;
mprintf("Number of experiments : %d\n",3*np);

//
// 1. We create a first design A
//
// Define a sampling for x1.
u = grand(np,1,"def");
x1 = cdfnor("X",mu1*ones(np,1),sigma1*ones(np,1),u,1-u);
// Define a sampling for x2.
u = grand(np,1,"def");
x2 = cdfnor("X",mu2*ones(np,1),sigma2*ones(np,1),u,1-u);
// Merge the two samplings
A = [x1 x2];
//
// 2. We create a first design B
//
// Define a sampling for x1.
u = grand(np,1,"def");
x1 = cdfnor("X",mu1*ones(np,1),sigma1*ones(np,1),u,1-u);
// Define a sampling for x2.
u = grand(np,1,"def");
x2 = cdfnor("X",mu2*ones(np,1),sigma2*ones(np,1),u,1-u);
// Merge the two samplings
B = [x1 x2];

//
// 3. Perform the first design A
//
// Perform the experiments
yA = Exemple (A);
Ey= mean(yA);
Ey_expectation= mu1*mu2;
Vy= variance(yA);
Vy_expectation = mu2^2*sigma1^2 + mu1^2*sigma2^2 + sigma1^2*sigma2^2;
mprintf("Expectation y = %.5f (expectation = %.5f)\n", Ey, Ey_expectation);
mprintf("Variance y = %.5f (expectation = %.5f)\n", Vy, Vy_expectation);

//
// 4. Compute S1
//
C=[A(:,1) B(:,2)];
yC1 = Exemple (C);
S1 = ( (yA'*yC1)/np - Ey^2 ) / Vy;
S1_expectation = ( mu2^2*sigma1^2 ) / Vy_expectation;
mprintf("First order sensitivity / x1 = %.5f (expectation = %.5f)\n", S1, S1_expectation);
re = abs(S1- S1_expectation)/S1_expectation;
mprintf("  Relative Error = %f\n", re);
//
// 5. Compute S2
//
C=[A(:,2) B(:,1)];
yC2 = Exemple (C);
S2 = ( (yA'*yC2)/np - Ey^2 ) / Vy;
S2_expectation = ( mu1^2*sigma2^2 ) / Vy_expectation;
mprintf("First order sensitivity / x2 = %.5f (expectation = %.5f)\n", S2, S2_expectation);
re = abs(S2- S2_expectation)/S2_expectation;
mprintf("  Relative Error = %f\n", re);


t = toc();
mprintf("Time = %f (s)\n", t);

