
// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_PolynomialChaos_map.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 


/* ==================================================================== */
// 
// polychaos_computeexp ( token , srv , method )
//   computes the coefficients of the polynomial chaos expansion
//     where srv is a setrandvar token and method is 
//     a string representing the computation algorithm
// polychaos_computeexp ( token , pc2 , invalue , varopt )
//   compute the coefficient based on another polynomial chaos and a reduced set of variables
//
int sci_polychaos_computeexp (char *fname)
{
	int token;
	PolynomialChaos * pc = NULL;
	int srvtoken;
	char * method;
	SetRandomVariable * srv = NULL;
	string stringmethod;
	int pctoken2;
	int nRowsInvalue, nColsInvalue;
	int nColsVaropt;
	int nopt;
	double * inputvector = NULL;
	double * doublevaropt = NULL;
	int nx;
	int * intvaropt = NULL;
	PolynomialChaos * pc2 = NULL;
	double * inputvectorNX = NULL;

	CheckRhs(3,4) ;
	CheckLhs(0,1) ;
	nisp_gettoken ( fname , 1 , &token );
	if (Rhs==3) {
		// polychaos_computeexp ( token , srv , method )
		nisp_gettoken ( fname , 2 , &srvtoken);
		nisp_GetOneChar ( fname , 3 , &method );
	} 
	else if (Rhs==4) 
	{
		// polychaos_computeexp ( token , pc2 , invalue , varopt )
		// How to make the difference between this calling sequence and the previous one?
		nisp_gettoken ( fname , 2 , &pctoken2);
		nisp_AssertVarType(fname , 3 , sci_matrix );
		GetRhsVarMatrixDouble ( 3, &nRowsInvalue, &nColsInvalue, &inputvector);
		nisp_AssertVarType(fname , 4 , sci_matrix );
		GetRhsVarMatrixDouble ( 4, &nopt, &nColsVaropt, &doublevaropt);
	}
	nisp_token2Polychaos ( fname , 1 , token , &pc );
	if (Rhs==3) {
		nisp_token2Setrandvar ( fname , 2 , srvtoken , &srv );
		stringmethod.assign ( method );
		pc -> ComputeChaosExpansion ( srv , stringmethod );
	}
	else if (Rhs==4) 
	{
		nx = pc-> GetDimensionInput();
		nisp_AssertNRows    ( fname , 3 , nRowsInvalue , 1 );
		nisp_AssertNColumns ( fname , 3 , nColsInvalue , nopt );
		nisp_AssertNColumns ( fname , 4 , nColsVaropt , 1 );
		nisp_token2Polychaos ( fname , 2 , pctoken2 , &pc2 );
		if ( (nopt <= 0) | (nopt > nx) ) {
			Scierror(999,_("%s: Inconsistent size of argument #%d and #%d: should have the same number of rows.\n"),fname,3,4);
			return 0;
		} 
		else 
		{
			intvaropt = (int *) malloc (nopt * sizeof (int));
			for(int i=0;i<nopt;i++) {
				nisp_Double2Integer(fname,4,doublevaropt[i],&(intvaropt[i]))
			}
			inputvectorNX = (double *) malloc ((nx+1) * sizeof (double));
			for(int i=1;i<nx;i++) {
				inputvectorNX[i] = inputvector[i-1];
			}
			pc-> ComputeChaosExpansion ( pc2 , inputvectorNX , intvaropt , nopt );
			free(intvaropt);
			free(inputvectorNX);
		} 
	}
	nisp_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */

