// 2009 - INRIA - Michael Baudin
// 2009 - Digiteo - Michael Baudin
/*!
  \file   nisp_va.h
  \brief  Class of random variables
*/
#ifndef _NISP_VA_H_
#define _NISP_VA_H_

#ifdef _MSC_VER
	#if LIBNISP_EXPORTS 
		#define NISP_IMPORTEXPORT __declspec (dllexport)
	#else
		#define NISP_IMPORTEXPORT __declspec (dllimport)
	#endif
#else
	#define NISP_IMPORTEXPORT
#endif


#include <string>
#include <vector>
using namespace std;

#undef __BEGIN_DECLS
#undef __END_DECLS
#ifdef __cplusplus
# define __BEGIN_DECLS extern "C" {
# define __END_DECLS }
#else
# define __BEGIN_DECLS /* empty */
# define __END_DECLS /* empty */
#endif

__BEGIN_DECLS

#ifdef _MSC_VER
#pragma warning( disable : 4251 )
#endif


//! Class of random variables
class NISP_IMPORTEXPORT RandomVariable {
 public :
  //! Law of the density probability
  string type;
  //! First parametre of the law
  double a;
  //! Second parametre of the law
  double b;
  //! Function of the law
  double (*function)(double,double);
 public:
   /** @name Constructor and Destructor
   **/
  //@{
	 // Caution !
	 // On blabla !!!
  //! Constructor from the law
  RandomVariable(string type);
  RandomVariable(char * type);
  //! Constructor from a law with one parameter
  // TODO : remove the string, take an integer as argument, define the possible integers as NISP_LAW_NORMAL, NISP_LAW_EXP, etc...
  RandomVariable(string type, double a);
  RandomVariable(char * name, double x);
  //! Constructor from a law with two parameters
  RandomVariable(string type, double a, double b);
  RandomVariable(char * name, double x, double y);
  //! Destructor
  ~RandomVariable();
  //@}
  //! Realisation of the random variable
  double GetValue();
  //TODO : get an array of random variables : double GetValue ( int n , double * value );
  //! Realisation from a realisation x of another RandomVariable *va
  double GetValue(RandomVariable *va, double x);
  //! Information : type of the law with its parameters
  void GetLog();
  void SetDefaultParameters();
  void AssignFunction();
  void CheckParameters();
  double pdfChange ( RandomVariable *mere, double x);
  double pdfChange ( double z);
};

__END_DECLS

#endif /* _NISP_VA_H_ */
