// Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

// <-- Non-regression test for bug 209 -->
//
// <-- URL -->
// http://forge.scilab.org/index.php/p/nisp/issues/209/
//
// <-- Short Description -->
// The getgroupinter function can fail.

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

function [ pc , srv , rvx1 , rvx2 ] = createMyPolychaos ()
 rvx1 = randvar_new("Normale");
 rvx2 = randvar_new("Uniforme");
 srv = setrandvar_new();
 setrandvar_addrandvar ( srv,rvx1);
 setrandvar_addrandvar ( srv,rvx2);
 ny = 1;
 pc = polychaos_new ( srv , ny );
 degre = 2;
 setrandvar_buildsample(srv,"Quadrature",degre);
 np = 9;
 polychaos_setsizetarget(pc,np);
 nx = polychaos_getdiminput(pc);
 ny = polychaos_getdimoutput(pc);
 outputdata = [
    0.1566233  
    0.2344555  
    0.3122878  
    1.1690525  
    1.75       
    2.3309475  
    2.1814817  
    3.2655445  
    4.3496073  
  ];
  polychaos_settarget(pc,outputdata);
  polychaos_setdegree(pc,degre);
endfunction


// Test polychaos_setgroupempty ( pc )
// Test polychaos_getgroupinter ( pc , ovar )
// Test polychaos_getgroupinter ( pc )
[ pc , srv , rvx1 , rvx2 ] = createMyPolychaos();
polychaos_computeexp(pc,srv,"Integration");
polychaos_setgroupempty ( pc );
polychaos_setgroupaddvar ( pc , 1 );
polychaos_setgroupaddvar ( pc , 2 );
computed = polychaos_getgroupinter ( pc );
expected = 0.04687499486871491;
assert_close ( computed , expected , %eps );
polychaos_destroy(pc);
setrandvar_destroy(srv);
randvar_destroy(rvx1);
randvar_destroy(rvx2);


