// Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

// <-- Non-regression test for bug 211 -->
//
// <-- URL -->
// http://forge.scilab.org/index.php/p/nisp/issues/211/
//
// <-- Short Description -->
// The "SmolyakGauss" sampling does not work.

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

vx1 = randvar_new("Normale");
vx2 = randvar_new("Uniforme");
srvx = setrandvar_new();
setrandvar_addrandvar ( srvx, vx1);
setrandvar_addrandvar ( srvx, vx2);
degre = 2;
setrandvar_buildsample(srvx,"SmolyakGauss",degre);
setrandvar_buildsample(srvx,"SmolyakFejer",degre);
setrandvar_buildsample(srvx,"SmolyakTrapeze",degre);
randvar_destroy(vx1);
randvar_destroy(vx2);
setrandvar_destroy(srvx);


