// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

nisp_destroyall ( );

// Example of what can go wrong...
// We create a first set of random variables.
srvx = setrandvar_new( 3 );
// We overwrite the first set, with the same variable.
srvx = setrandvar_new( 3 );
// We have lost one setrandvar.
// We could recover it with
tokensmat = setrandvar_tokens();
assert_equal ( tokensmat , [0 1] );
// To destroy all the lost object, we can as well save
// some time and destroy them all at once.
nisp_destroyall ( );
// There is no more setrandvar in use.
tokensmat = setrandvar_tokens();
assert_equal ( tokensmat , [] );

//
// Test with random variables
rv1 = randvar_new("Normale" , 0 , 1);
rv2 = randvar_new("Normale" , 0 , 1);
tokensmat = randvar_tokens();
assert_equal ( tokensmat , [0 1] );
nisp_destroyall ( );
tokensmat = randvar_tokens();
assert_equal ( tokensmat , [] );

//
// Test with chaos polynomials
nx = 3;
srvx1 = setrandvar_new( nx );
pc1 = polychaos_new ( srvx1 , 1 );
srvx2 = setrandvar_new( nx );
pc2 = polychaos_new ( srvx2 , 1 );
tokensmat = polychaos_tokens();
assert_equal ( tokensmat , [0 1] );
nisp_destroyall ( );
tokensmat = polychaos_tokens();
assert_equal ( tokensmat , [] );

