// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// Test the NISP support functions for verbose levels
//
level = nisp_verboselevelget();
assert_equal ( level , 0 );
nisp_verboselevelset ( 1 );
level = nisp_verboselevelget();
assert_equal ( level , 1 );
nisp_verboselevelset ( 0 );
level = nisp_verboselevelget();
assert_equal ( level , 0 );

// Test wrong verbose level
instr="nisp_verboselevelset ( -1 )";
ierr = execstr(instr,"errcatch");
assert_equal ( ierr <> 0 , %t );
errmsg = lasterror();
assert_equal ( errmsg , "NISP: Error at the library level:NISP - ERRORUnknown verbose level -1" );


