
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
// Copyright (C) 2010 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

// Try polychaos_tokens
// At start, no polychaos should exist.
pclist = polychaos_tokens();
assert_equal ( pclist , [] );
nbpc = polychaos_size();
assert_equal ( nbpc , 0 );

// Test polychaos_new ( srv , ny )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
pc = polychaos_new ( srv , 10 );
pclist = polychaos_tokens();
assert_equal ( size(pclist,2) , 1 );
nbpc = polychaos_size();
assert_equal ( nbpc , 1 );
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );
pclist = polychaos_tokens();
assert_equal ( size(pclist,2) , 0 );
nbpc = polychaos_size();
assert_equal ( nbpc , 0 );

// TODO : test this : token = polychaos_new ( file )


// Test polychaos_new ( pc , nopt , varopt )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
pc2 = polychaos_new ( srv , 10 );
nopt = 1;
varopt = 1;
// TODO : how to make this work ?
//pc = polychaos_new ( pc2 , nopt , varopt )
polychaos_destroy ( pc2 );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// Test polychaos_setdegree ( pc , no )
// Test no = polychaos_getdegree ( pc )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
pc = polychaos_new ( srv , 10 );
polychaos_setdegree ( pc , 3 );
no = polychaos_getdegree ( pc );
assert_equal ( no , 3 );
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// Test polychaos_freememory ( pc )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
pc = polychaos_new ( srv , 10 );
polychaos_freememory ( pc );
polychaos_freememory ( pc );
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// Test polychaos_setdimoutput ( pc , ny )
// Test ny = polychaos_getdimoutput ( pc )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
pc = polychaos_new ( srv , 10 );
ny = polychaos_getdimoutput ( pc );
assert_equal ( ny , 10 );
polychaos_setdimoutput ( pc , 11 );
ny = polychaos_getdimoutput ( pc );
assert_equal ( ny , 11 );
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// Test polychaos_setsizetarget ( pc , np )
// Test np = polychaos_getsizetarget ( pc )
// Test polychaos_freememtarget ( pc )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
ny = 10;
pc = polychaos_new ( srv , ny );
np = 3;
polychaos_setsizetarget ( pc , np );
np = polychaos_getsizetarget ( pc );
assert_equal ( np , 3 );
polychaos_freememtarget ( pc );
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// Test polychaos_settarget ( pc , k , j , output )
// Test output = polychaos_gettarget ( pc , k , j )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
ny = 10;
pc = polychaos_new ( srv , ny );
np = 3;
polychaos_setsizetarget ( pc , np );
for k = 1:np
  for j = 1:ny
    expected = j + k;
    polychaos_settarget ( pc , k , j , expected );
    computed = polychaos_gettarget ( pc , k , j );
    assert_close ( computed , expected , %eps );
  end
end
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// Test polychaos_settarget ( pc , k , output ) with output as vector 
// Test output = polychaos_gettarget ( pc , k )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
ny = 10;
pc = polychaos_new ( srv , ny );
np = 3;
polychaos_setsizetarget ( pc , np );
for k = 1:np
  expected = k + (1:ny);
  polychaos_settarget ( pc , k , expected );
  computed = polychaos_gettarget ( pc , k );
  assert_close ( computed , expected , %eps );
end
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// Test polychaos_settarget ( pc , output ) with output as matrix 
// Test output = polychaos_gettarget ( pc )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
ny = 10;
pc = polychaos_new ( srv , ny );
np = 3;
polychaos_setsizetarget ( pc , np );
expected = (1:np).' * (1:ny);
polychaos_settarget ( pc , expected );
computed = polychaos_gettarget ( pc );
assert_close ( computed , expected , %eps );
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// Test polychaos_freememtarget ( pc )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
ny = 10;
pc = polychaos_new ( srv , ny );
np = 3;
polychaos_setsizetarget ( pc , np );
expected = (1:np).' * (1:ny);
polychaos_settarget ( pc , expected );
polychaos_freememtarget ( pc );
// TODO : what to assert ?
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// TODO : Test polychaos_readtarget ( pc ) but what is to be in the file ?

// Test polychaos_getdiminput ( pc )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
ny = 10;
pc = polychaos_new ( srv , ny );
computed = polychaos_getdiminput ( pc );
expected = 2;
assert_equal ( computed , expected );
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// Test polychaos_getdimexp ( pc )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
ny = 10;
pc = polychaos_new ( srv , ny );
computed = polychaos_getdimexp ( pc );
expected = 1;
assert_equal ( computed , expected );
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

// Test polychaos_getlog ( pc )
rv1 = randvar_new("Normale");
rv2 = randvar_new("Uniforme");
srv = setrandvar_new ();
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
ny = 10;
pc = polychaos_new ( srv , ny );
polychaos_getlog ( pc );
// TODO : what to assert ?
polychaos_destroy ( pc );
setrandvar_destroy ( srv );
randvar_destroy ( rv1 );
randvar_destroy ( rv2 );

function y = Exemple (x)
y(1) = x(1) * x(2);
endfunction

// Test polychaos_computeexp ( pc , srv2 , "Integration");
// TODO : test with regression
rv1 = randvar_new("Normale",1.0,0.5);
rv2 = randvar_new("Uniforme",1.0,2.5);
srv = setrandvar_new();
setrandvar_addrandvar ( srv,rv1);
setrandvar_addrandvar ( srv,rv2);
rvx1 = randvar_new("Normale");
rvx2 = randvar_new("Uniforme");
srv2 = setrandvar_new();
setrandvar_addrandvar ( srv2,rvx1);
setrandvar_addrandvar ( srv2,rvx2);
ny = 1;
pc = polychaos_new ( srv2 , ny );
degre = 2;
setrandvar_buildsample(srv2,"Quadrature",degre);
setrandvar_buildsample( srv , srv2 );
np = setrandvar_getsize(srv);
polychaos_setsizetarget(pc,np);
nx = polychaos_getdiminput(pc);
ny = polychaos_getdimoutput(pc);
for k=1:np
  inputdata = setrandvar_getsample(srv,k);
  outputdata = Exemple(inputdata);
  polychaos_settarget(pc,k,outputdata);
end
polychaos_setdegree(pc,degre);
polychaos_computeexp(pc,srv2,"Integration");
// TODO : what to assert ?
polychaos_destroy(pc);
setrandvar_destroy ( srv );
setrandvar_destroy ( srv2 );
randvar_destroy(rv1);
randvar_destroy(rv2);
randvar_destroy(rvx1);
randvar_destroy(rvx2);

function [ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos ()
 //
 rvx1 = randvar_new("Normale");
 rvx2 = randvar_new("Uniforme");
 srvx = setrandvar_new();
 setrandvar_addrandvar ( srvx , rvx1 );
 setrandvar_addrandvar ( srvx , rvx2 );
 //
 vu1 = randvar_new("Normale",1.0,0.5);
 vu2 = randvar_new("Uniforme",1.0,2.5);
 srvu = setrandvar_new();
 setrandvar_addrandvar ( srvu,vu1);
 setrandvar_addrandvar ( srvu,vu2);
 //
 ny = 1;
 pc = polychaos_new ( srvx , ny );
 degre = 2;
 setrandvar_buildsample(srvx,"Quadrature",degre);
 setrandvar_buildsample( srvu , srvx );
 np = setrandvar_getsize(srvx);
 polychaos_setsizetarget(pc,np);
 nx = polychaos_getdiminput(pc);
 ny = polychaos_getdimoutput(pc);
 for k=1:np
    inputdata = setrandvar_getsample(srvu,k);
    outputdata = Exemple(inputdata);
    polychaos_settarget(pc,k,outputdata);
  end
  polychaos_setdegree(pc,degre);
endfunction

function cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 )
  polychaos_destroy(pc);
  setrandvar_destroy(srvx);
  randvar_destroy(rvx1);
  randvar_destroy(rvx2);
  setrandvar_destroy(srvu);
  randvar_destroy(vu1);
  randvar_destroy(vu2);
endfunction


// Test polychaos_getmean ( pc , ovar )
// Test polychaos_getmean ( pc )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
computed = polychaos_getmean ( pc , 1 );
expected = 1.75;
// TODO : is 1.e-8 correct ?
assert_close ( computed , expected , 1.e-8 );
computed = polychaos_getmean ( pc );
expected = 1.75;
assert_close ( computed , expected , 1.e-8 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );


// Test polychaos_getvariance ( pc , ovar )
// Test polychaos_getvariance ( pc )
// TODO : test getvariance with ny>1
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
computed = polychaos_getvariance ( pc , 1 );
expected = 1.;
// TODO : is 1.e-7 correct ?
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getvariance ( pc );
expected = 1.;
assert_close ( computed , expected , 1.e-7 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_getcovariance ( pc , ovar1 , ovar2 )
// Test polychaos_getcovariance ( pc )
// TODO : test getcovariance with ny>1
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
computed = polychaos_getcovariance ( pc , 1 , 1 );
expected = 1.;
// TODO : is 1.e-7 correct ?
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getcovariance ( pc );
expected = 1.;
assert_close ( computed , expected , 1.e-7 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_getcorrelation ( pc , ovar1 , ovar2 )
// Test polychaos_getcorrelation ( pc )
// TODO : test getcorrelation with ny>1
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
computed = polychaos_getcorrelation ( pc , 1 , 1 );
expected = 1.;
// TODO : is 1.e-7 correct ?
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getcorrelation ( pc );
expected = 1.;
assert_close ( computed , expected , 1.e-7 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_getindexfirst ( pc , ivar , ovar )
// Test polychaos_getindexfirst ( pc , ivar )
// Test polychaos_getindexfirst ( pc )
// TODO : test polychaos_getindexfirst with ny>1
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
computed = polychaos_getindexfirst ( pc , 1 , 1 );
expected = 0.7656250;
// TODO : is 1.e-7 correct ?
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getindexfirst ( pc , 1 );
expected = 0.7656250;
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getindexfirst ( pc );
expected = [
0.765625
0.1875
];
assert_close ( computed , expected , 1.e-7 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_getindextotal ( pc , ovar1 , ovar2 )
// Test polychaos_getindextotal ( pc , ovar1 )
// Test polychaos_getindextotal ( pc )
// TODO : test polychaos_getindextotal with ny>1
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
computed = polychaos_getindextotal ( pc , 1 , 1 );
expected = 0.8125;
// TODO : is 1.e-7 correct ?
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getindextotal ( pc , 1 );
expected = 0.8125;
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getindextotal ( pc );
expected = [
    0.8125     
    0.234375
];
assert_close ( computed , expected , 1.e-7 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_getmultiind ( pc )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
polychaos_getmultind ( pc );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_getgroupind ( pc , ovar )
// Test polychaos_getgroupind ( pc )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
computed = polychaos_getgroupind ( pc , 1 );
expected = 0.0;
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getgroupind ( pc );
expected = 0.0;
assert_close ( computed , expected , 1.e-7 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_setgroupempty ( pc )
// Test polychaos_getgroupinter ( pc , ovar )
// Test polychaos_getgroupinter ( pc )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
polychaos_setgroupempty ( pc );
computed = polychaos_getgroupinter ( pc , 1 );
expected = 0.0;
assert_close ( computed , expected , %eps );
computed = polychaos_getgroupinter ( pc );
expected = 0.0;
assert_close ( computed , expected , %eps );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_setgroupempty ( pc )
// Test polychaos_setgroupaddvar ( pc , ivar )
// Test polychaos_getgroupinter ( pc , ovar )
// Test polychaos_getgroupinter ( pc )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
polychaos_setgroupempty ( pc );
polychaos_setgroupaddvar ( pc , 2 );
computed = polychaos_getgroupinter ( pc , 1 );
expected = 0.1875;
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getgroupinter ( pc );
expected = 0.1875;
assert_close ( computed , expected , 1.e-7 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_setgroupempty ( pc )
// Test polychaos_getgroupinter ( pc , ovar )
// Test polychaos_getgroupinter ( pc )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
polychaos_setgroupempty ( pc );
polychaos_setgroupaddvar ( pc , 1 );
polychaos_setgroupaddvar ( pc , 2 );
computed = polychaos_getgroupinter ( pc );
expected = 0.04687499486871491;
assert_close ( computed , expected , 1.e-6 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_buildsample ( pc , type , np , order );
// Test polychaos_getinvquantile ( pc , threshold , ovar )
// Test polychaos_getgroupinter ( pc , threshold )
nisp_initseed ( 0 );
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
order = 1;
np = 10;
polychaos_buildsample ( pc , "MonteCarlo" , np , order );
threshold = 0.5;
computed = polychaos_getinvquantile ( pc , threshold , 1 );
expected = 0.1;
assert_close ( computed , expected , %eps );
computed = polychaos_getinvquantile ( pc , threshold );
expected = 0.1;
assert_close ( computed , expected , %eps );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_compute ( pc , x )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
x = [0.1 0.9];
computed = polychaos_compute ( pc , x );
u(1) = randvar_getvalue ( vu1 , rvx1 , x(1) );
u(2) = randvar_getvalue ( vu2 , rvx2 , x(2) );
expected = Exemple(u);
assert_close ( computed , expected , 1.e-7 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_getquantile ( pc , alpha , ovar )
// Test polychaos_getquantile ( pc , alpha );
// TODO : bug under : linux = 1.79917, windows = 1.556641
// TODO : increase the number of experiments np from 10 to 10000 or simplify the model.
// TODO : For example: if X is uniform, if the model is Y=X then the variance of the quantile is alpha*(1-alpha)/np

nisp_initseed ( 0 );
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
order = 1;
np = 10;
polychaos_buildsample ( pc , "MonteCarlo" , np , order );
alpha = 0.5;
computed = polychaos_getquantile ( pc , alpha , 1 );
expected = 1.556641;
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getquantile ( pc , alpha );
expected = 1.556641;
assert_close ( computed , expected , 1.e-7 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_getquantwilks ( pc , walpha , wbeta , ovar )
// Test polychaos_getquantwilks ( pc , walpha , wbeta );
// TODO : windows = 1.8512433, linux = 2.2377241
nisp_initseed ( 0 );
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
order = 1;
np = 10;
polychaos_buildsample ( pc , "MonteCarlo" , np , order );
walpha = 0.5;
wbeta = 0.75;
computed = polychaos_getquantwilks ( pc , walpha , wbeta , 1 );
expected = 1.8512433;
assert_close ( computed , expected , 1.e-7 );
computed = polychaos_getquantwilks ( pc , walpha , wbeta );
expected = 1.8512433;
assert_close ( computed , expected , 1.e-7 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_getsample ( pc , k , ovar )
// Test polychaos_getsample ( pc , k )
// Test polychaos_getsample ( pc )
nisp_initseed ( 0 );
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
order = 1;
np = 100;
polychaos_buildsample ( pc , "MonteCarlo" , np , order );
for k=1:np
  ovar = 1;
  sampling(k) = polychaos_getsample ( pc , k , 1 );
end
computed = mean(sampling);
expected = 1.75;
assert_close ( computed , expected , 1.e-1 );
for k=1:np
  ovar = 1;
  sampling(k) = polychaos_getsample ( pc , k );
end
computed = mean(sampling);
expected = 1.75;
assert_close ( computed , expected , 1.e-1 );
sampling = polychaos_getsample ( pc );
computed = mean(sampling);
expected = 1.75;
assert_close ( computed , expected , 1.e-1 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_computeexp ( token , pc , invalue , varopt ) 
// TODO : test this !
rv1 = randvar_new("Normale",1.0,0.5);
rv2 = randvar_new("Uniforme",1.0,2.5);
srvx = setrandvar_new();
setrandvar_addrandvar ( srvx,rv1);
setrandvar_addrandvar ( srvx,rv2);
rvx1 = randvar_new("Normale");
rvx2 = randvar_new("Uniforme");
srv2 = setrandvar_new();
setrandvar_addrandvar ( srv2,rvx1);
setrandvar_addrandvar ( srv2,rvx2);
ny = 1;
pc = polychaos_new ( srv2 , ny );
pc2 = polychaos_new ( srv2 , ny );
//polychaos_computeexp ( pc , pc2 , [4.0 5.0] , [1 0]);
// TODO : what to assert ?
polychaos_destroy(pc);
polychaos_destroy(pc2);
randvar_destroy(rv1);
randvar_destroy(rv2);
randvar_destroy(rvx1);
randvar_destroy(rvx2);

// Test polychaos_getanova ( pc )
// Test polychaos_getanova ( pc , r )
// Test polychaos_getanovaord ( pc )
// Test polychaos_getanovaord ( pc , threshold )
// Test polychaos_getanovaord ( pc , threshold , r )
// Test polychaos_getanovaordco ( pc )
// Test polychaos_getanovaordco ( pc , threshold )
// Test polychaos_getanovaordco ( pc , threshold , r )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
polychaos_getanova ( pc );
polychaos_getanova ( pc , 1 );
polychaos_getanovaord ( pc );
polychaos_getanovaord ( pc , 0.1 );
polychaos_getanovaord ( pc , 0.1 , 1 );
polychaos_getanovaordco ( pc );
polychaos_getanovaordco ( pc , 0.1 );
polychaos_getanovaordco ( pc , 0.1 , 1 );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_realisation ( pc )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
polychaos_realisation ( pc );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// fileexists --
//   Returns true if the file exists,
//   returns false if the file does not exist.
function e = fileexists ( filename )
  e = (fileinfo(filename)~=[])
endfunction

// Test polychaos_save ( pc , file )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
polychaos_save ( pc , TMPDIR+"/myfile.txt" );
computed = fileexists ( TMPDIR+"/myfile.txt" );
assert_equal ( computed , %T );
deletefile ( TMPDIR+"/myfile.txt" );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );

// Test polychaos_generatecode ( pc , filename , name )
[ pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 ] = createMyPolychaos();
polychaos_computeexp(pc,srvx,"Integration");
polychaos_generatecode ( pc , TMPDIR+"/myfile.c" , "foo" );
computed = fileexists ( TMPDIR+"/myfile.c" );
assert_equal ( computed , %T );
// TODO : generate a templated gateway and replace "<T_NAME>" with "foo"
//files=[TMPDIR+"/myfile.c"];
//ilib_build('foo',[],files,[]);
deletefile ( TMPDIR+"/myfile.c" );
cleanupMyPolychaos ( pc , srvx , rvx1 , rvx2 , srvu , vu1 , vu2 );


